@@ -24,6 +24,19 @@ translate(a):translate a
 print_load:
 progess_bar(title,range):bar for linux
 progess_bar_win(title,range):bar for windows
+simplepygame:
+it is simple than pygame,but it is only a pygame tool!
+font(filename,size):set font
+text(text,colorlist,bgcolor=None):show text
+update():update
+isquit():is quit?
+autoquit():quit
+quitis():auto isquit autoquit
+quitwhile():quit is for while ...:
+bgmsc:play background music
+msc():sound value
+playmsc(msc):msc() + autoplay
+nobgm():stop background music
 '''
 def logo_allenlib():
     print('allenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib')
\ No newline at end of file
